@@ -2,7 +2,7 @@
 
 import click
 import os
-from .clslq_utils import pipguess
+from clspy.utils import pipguess
 
 
 @click.option('--pypi',
